==> react-markplus-0.2.6.tgz: package/lib/index.js <==
import { ConfigProvider } from "antd";
import { manage } from "manate";
import React, { useEffect, useMemo } from "react";
import Layout from "./components/layout.js";
import { Store } from "./store.js";
export const defaultToolbarItems = [
    "about",
    "|",
    "bold",
    "italic",
    "strikethrough",
    "underline",
    "mark",
    "|",
    "emoji",
    "fontawesome",
    "|",
    "quote",
    "unordered-list",
    "ordered-list",
    "unchecked-list",
    "checked-list",
    "|",
    "link",
    "image",
    "code",
    "table",
    "|",
    "math",
    "flowchart",
];
const MarkPlus = (props) => {
    const { markdown, mode, toolbar, theme, toolbarItems } = props;
    const store = useMemo(() => {
        return manage(new Store());
    }, []);
    useEffect(() => {
        store.preferences.mode = mode ?? "both";
        store.preferences.toolbar = toolbar ?? "show";
        store.preferences.theme = theme ?? "auto";
        store.preferences.toolbarItems = toolbarItems ?? defaultToolbarItems;
        store.onChange = props.onChange ?? (() => { });
    }, [mode, toolbar, theme, toolbarItems, store, props.onChange]);
    useEffect(() => {
        if (store.editor) {
            const currentSelection = store.editor.state.selection;
            store.editor.dispatch({
                changes: {
                    from: 0,
                    to: store.editor.state.doc.length,
                    insert: markdown ?? "",
                },
                selection: currentSelection,
            });
        }
    }, [markdown, store.editor]);
    return (React.createElement(ConfigProvider, { theme: {
            token: {
                colorPrimary: "#00b96b",
            },
        } },
        React.createElement(Layout, { store: store })));
};
export default MarkPlus;

==> react-markplus-0.2.8.tgz: package/lib/index.js <==
import { ConfigProvider } from "antd";
import { manage } from "manate";
import React, { forwardRef, useEffect, useImperativeHandle, useMemo, } from "react";
import Layout from "./components/layout.js";
import { Store } from "./store.js";
export const defaultToolbarItems = [
    "about",
    "|",
    "bold",
    "italic",
    "strikethrough",
    "underline",
    "mark",
    "|",
    "emoji",
    "fontawesome",
    "|",
    "quote",
    "unordered-list",
    "ordered-list",
    "unchecked-list",
    "checked-list",
    "|",
    "link",
    "image",
    "code",
    "table",
    "|",
    "math",
    "flowchart",
];
const MarkPlus = forwardRef((props, ref) => {
    const { markdown, mode, toolbar, theme, toolbarItems } = props;
    const store = useMemo(() => {
        return manage(new Store());
    }, []);
    useImperativeHandle(ref, () => ({
        getStore: () => store, // Expose the `store` variable
    }));
    useEffect(() => {
        store.preferences.mode = mode ?? "both";
        store.preferences.toolbar = toolbar ?? "show";
        store.preferences.theme = theme ?? "auto";
        store.preferences.toolbarItems = toolbarItems ?? defaultToolbarItems;
        store.onChange = props.onChange ?? (() => { });
    }, [mode, toolbar, theme, toolbarItems, store, props.onChange]);
    useEffect(() => {
        if (store.editor) {
            const currentSelection = store.editor.state.selection;
            store.editor.dispatch({
                changes: {
                    from: 0,
                    to: store.editor.state.doc.length,
                    insert: markdown ?? "",
                },
                selection: currentSelection,
            });
        }
    }, [markdown, store.editor]);
    return (React.createElement(ConfigProvider, { theme: {
            token: {
                colorPrimary: "#00b96b",
            },
        } },
        React.createElement(Layout, { store: store })));
});
export default MarkPlus;
